extensions [ vid ]   ; for recording video

; the following breeds (agents) are in the model:
breed [large-farmers large-farmer]
breed [medium-farmers medium-farmer]
breed [small-farmers small-farmer]

; each turtle (farmer) owns patch-cluster and land-size through which the turtle (farmer) creates its own farm at the beginning of each step
turtles-own [
  own-patch-cluster
  farmers-vulnerability
  land-size
]

; Each breed (agent) owns some actions that are either available or not-available to be taken in different time steps
large-farmers-own [
act2 ; Desalination, if 0 means it has not been done before by agent and is available, if 1 means it has been done before by agent and cannot be selected anymore.
act3 ; purchasing water, to count nr of time water is purchased by each farmer
]
medium-farmers-own [
act3-m   ; irrigation system change, if 0 means it has not been done before and is available, if 1 means it has been done and is not available.
land-document     ; 30% of medium farmers do not have land document, which means land-document=0
]
small-farmers-own [
act1-s  ;irrigation system change, if 0 means it has not been done before and is available, if 1 means it has been done and is not available.
act2-s  ;wells-turn off, there is a limitation for this action: not more than 4 times per year
land-document   ; 50% of small farmers do not have land-document, which means land-document=0
]
patches-own [
  patch-cluster  ; to creat farms
  belongs-to     ; each patch belongs to one farmer, and many patch can belong to one farmer. But one patch cannot belong to more than one farmer
;ecological properties of each patch
  GW-level-depth
  GW-level
  well-depth
  allowed-well-depth ; this value can change later
  GW-quality
  land-subsidence
  farm-state   ; 0 is nothing, 1 means patch is avalable for the action of "selling-land" , 2 means patch is available for the action of "integrating-land"
  well-state   ; 0 is nothing, 1 means patch is available for the action of "selling-water"
  GW-use
  GW-use-initial
  GW-use-change
  pistachio-production
]





to setup
  clear-all
  ask patches [set GW-level 1]   ; this is to set GW-level of empty patches (out of 7 sub-regions) 1 and then change the GW-level of 7 sub-regions to their real amount
  make-patch-cluster   ; to make the 7 sub-regions
  set-default-shape turtles "person farmer"
  create-large-farmers 21 [set size 3]
  create-medium-farmers 49 [set size 2]
  ask n-of 34 medium-farmers [ set land-document 1]  ; 70% of the medium farmers have land-document for their farms
  create-small-farmers 84 [set size 1]
  ask n-of 42 small-farmers [set land-document 1]  ; 50% of small farmers have land-document for their farms
  ask patches [
    set belongs-to nobody    ; before creating the farms (initialise-farm)
  ]
  ask turtles [
    set own-patch-cluster 0
  ]
  initialise-farms
  ask patches with [pcolor = 0] [
  set GW-use 0
  set pistachio-production 0
  ]
  ask turtles[
    set land-size count patches with [belongs-to = myself]
  ]
  ask n-of 25 medium-farmers [         ; to show 50% of medium-farmers are willing to ingrate their lands
    ask patches with [belongs-to = myself] [
      set farm-state 2
    ]
  ]
  reset-ticks

  if vid:recorder-status = "recording" [ vid:record-interface ]

end

; to creat 7 patch-cluster (sub-regions) and asign their initial property valus. each subregion consists of 15*15 cells.
to make-patch-cluster

  ask patches [
    if ; to make cluster for region 1
    (pxcor >= -22) and (pxcor <= -8) and (pycor >= 8) and (pycor <= 22)
    [set patch-cluster 1
     set GW-level-depth 90
     set GW-level 90
     set well-depth 95 + random 5
     set allowed-well-depth 100
     set GW-quality 1
     set GW-use-initial 120
      set GW-use 120
     set pistachio-production 2]
    if ; to make cluster for region 2
    (pxcor >= -22) and (pxcor <= -8) and (pycor >= -7) and (pycor <= 7)
    [set patch-cluster 2
     set GW-level-depth 100  ; previous 90
     set GW-level 100
     set well-depth 105 + random 5   ; D = 10
     set allowed-well-depth 105
     set GW-quality 1
     set GW-use-initial 121
      set GW-use 121
     set pistachio-production 2]
    if ; to make cluster for region 3
    (pxcor >= -22) and (pxcor <= -8) and (pycor >= -22) and (pycor <= -8)
    [set patch-cluster 3
     set land-subsidence 9
     set GW-level-depth 120  ; previous 110
     set GW-level 120
     set well-depth 125 + random 10
     set allowed-well-depth 145
     set GW-quality 7
     set GW-use-initial 122
      set GW-use 122
     set pistachio-production 2]
    if ; to make cluster for region 4
    (pxcor >= -7) and (pxcor <= 7) and (pycor >= -22) and (pycor <= -8)
    [set patch-cluster 4
     set land-subsidence 3
     set GW-level-depth 115  ; previous 100
     set GW-level 115
     set well-depth 120 + random 10
     set allowed-well-depth 145
     set GW-quality 9
     set GW-use-initial 122
      set GW-use 122
     set pistachio-production 2]
    if ; to make cluster for region 5
    (pxcor >= 8) and (pxcor <= 22) and (pycor >= -22) and (pycor <= -8)
    [set patch-cluster 5
     set land-subsidence 5
     set GW-level-depth 120  ; previous 110
     set GW-level 120
     set well-depth 130 + random 10
     set allowed-well-depth 150
     set GW-quality 9
     set GW-use-initial 122
      set GW-use 122
     set pistachio-production 2]
    if ; to make cluster for region 6
    (pxcor >= 8) and (pxcor <= 22) and (pycor >= -7) and (pycor <= 7)
    [set patch-cluster 6
     set land-subsidence 9
     set GW-level-depth 120   ; previous 110
     set GW-level 120
     set well-depth 135 + random 5
     set allowed-well-depth 150
     set GW-quality 5
     set GW-use-initial 124
      set GW-use 124
     set pistachio-production 2]
    if ; to make cluster for region 7
    (pxcor >= 8) and (pxcor <= 22) and (pycor >= 8) and (pycor <= 22)
    [set patch-cluster 7
     set land-subsidence 9
     set GW-level-depth 110   ; previous 100
     set GW-level 110
     set well-depth 125 + random 10
     set allowed-well-depth 140
     set GW-quality 5
     set GW-use-initial 124
      set GW-use 124
     set pistachio-production 2]
    ]

end


; distributing equal numebr of large, medium and small farmers into 7 sub-regions
to initialise-farms

  let n 1
  while [n <= 7] [ ;since there are 7 sub-regions

    ask n-of 3 large-farmers with [own-patch-cluster = 0] [
    move-to one-of patches with [ patch-cluster = n and belongs-to = nobody] ; to move to an empty patch in one of the 7 sub-regions
      set own-patch-cluster n
    make-Lfarm-clusters
  ]
  ask n-of 7 medium-farmers with [own-patch-cluster = 0] [
    move-to one-of patches with [ patch-cluster = n and belongs-to = nobody]
      set own-patch-cluster n
    make-Mfarm-clusters
  ]
    ask n-of 12 small-farmers with [own-patch-cluster = 0] [
    move-to one-of patches with [ patch-cluster = n and belongs-to = nobody]
      set own-patch-cluster n
    make-Sfarm-clusters
  ]

  set n  n + 1
  ]

end

; each agent creates its own patch-cluster (farm). Number of patches for each breed comes from the size of lands for large, medium and small farmers. Each patch represent 5 ha farm.
to make-Lfarm-clusters   ; this is for the large-farmers
    ask patch-here [
      set pcolor 65    ; large farmers' farms are represented in green
      set belongs-to myself ]

  let n 1
  while [n <= 7] [
  repeat 6 + random-float 3 [   ; to keep the size of the large farms between 80ha and 250ha.
      let mycurrentfarm patches with [ belongs-to = myself ]
      let candidates no-patches    ; create empty agentset
      ask mycurrentfarm [
       set candidates ( patch-set candidates one-of neighbors4 with [ patch-cluster = n and belongs-to = nobody] )

      if ( count candidates > 0 )
        [ ask one-of candidates [
          set pcolor 65
          set belongs-to [belongs-to] of myself
          ]
        ]
      ]
    ]
    set n  n + 1
  ]

end


to make-Mfarm-clusters   ; this is for the medium-farmers
    ask patch-here [
      set pcolor 25
      set belongs-to myself]

  let n 1
  while [n <= 7] [
  repeat 2 + random-float 3 [    ; to keep the size of the medium farms between 15ha and 80ha
      let mycurrentfarm patches with [ belongs-to = myself ]
      let candidates no-patches   ; create empty agentset
       ask mycurrentfarm [
       set candidates ( patch-set candidates one-of neighbors4 with [ patch-cluster = n and belongs-to = nobody] )

      if ( count candidates > 0 )
      [ ask one-of candidates [
          set pcolor 25
          set belongs-to [belongs-to] of myself
          ]
        ]
      ]
    ]
   set n  n + 1
  ]


end


to make-Sfarm-clusters     ; this is for the small-farmers
    ask patch-here [
      set pcolor 45
    set belongs-to myself]

  let n 1
  while [n <= 7] [
  repeat random-float 2 [     ; to keep the size of the small farms between 5 and 15ha
    let mycurrentfarm patches with [ belongs-to = myself ]
    let candidates no-patches; create empty agentset
    ask mycurrentfarm [
      set candidates ( patch-set candidates one-of neighbors4 with [ patch-cluster = n and belongs-to = nobody] )

      if ( count candidates > 0 )
      [ ask one-of candidates [
        set pcolor 45
        set belongs-to [belongs-to] of myself
        ]
      ]
    ]
  ]
    set n  n + 1
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go

  ask patches [update-patches]
  if (ticks mod 12 = 0)[
    ask large-farmers [
      if (con1 = true) [execute-action-1]     ; to buy lands every year by large-farmers
    ]
  ]
; each agent checks its GW-access. If it is satisfies with its GW-access it goes to the next step (does nothing in the current time step), if not satisfied it enters its action list.
  ask large-farmers [ ifelse GW-access = true [] [large-action-list]]
  ask medium-farmers [ ifelse GW-access = true [] [medium-action-list]]
  ask small-farmers [ ifelse GW-access = true [] [small-action-list]]

  ; for the latge-farmers who become medium because of their land shrinking
   tick
  if ticks >= 181 [stop]

  if vid:recorder-status = "recording" [ vid:record-interface ]

end

to start-recorder
    carefully [ vid:start-recorder ] [ user-message error-message ]
end

to reset-recorder
    let message (word
    "If you reset the recorder, the current recording will be lost."
    "Are you sure you want to reset the recorder?")
  if vid:recorder-status = "inactive" or user-yes-or-no? message [
    vid:reset-recorder
  ]
end

to save-recording
    if vid:recorder-status = "inactive" [
    user-message "The recorder is inactive. There is nothing to save."
    stop
  ]
  ; prompt user for movie location
  user-message (word
    "Choose a name for your movie file (the "
    ".mp4 extension will be automatically added).")
  let path user-new-file
  if not is-string? path [ stop ]  ; stop if user canceled
  ; export the movie
  carefully [
    vid:save-recording path
    user-message (word "Exported movie to " path ".")
  ] [
    user-message error-message
  ]
end

to update-patches

  set GW-level-depth ( GW-level-depth + 0.2 )
  set GW-level GW-level * 1.01
  let GW-level-change ( GW-level * (1 + GW-use-change * 0.8) - GW-level ) / GW-level
  set pistachio-production pistachio-production * (1 + GW-level-change * 0.6)  ; to represent impact of GW-level on pistachio-production
  set GW-level GW-level * (1 + GW-use-change * 0.8)  ; to represent impact of GW-use on GW-level-change
  if  GW-level-depth > well-depth  [set pistachio-production 0] ; to stop production after the groundwater level goes lower than well's depth
  set GW-use-change 0

end

 to-report con1

; Condition1 is if there is any farm in the neighbourhood of this farm, farmer of which is willing to sell-off his/her farm
  let my-neighbors (patch-set [ neighbors ] of patches with [belongs-to = myself] ) ; without own patches

  let other-my-neighbors my-neighbors with [belongs-to != myself]
  show other-my-neighbors
  let patches-to-buy other-my-neighbors with [ farm-state = 1 ]
  ifelse ( count patches-to-buy > 0 and policy != 1)
  [report true] [ report false]

end

 to execute-action-1

; action-1 is to buy-off neighbor's farm, meaning the farms in the neighbour get belong to the buyer-farmer, and impact of this action is implemented on the patches' properties.

  let my-neighbors (patch-set [ neighbors ] of patches with [belongs-to = myself])
  let other-my-neighbors my-neighbors with [belongs-to != myself]
  let patches-to-buy other-my-neighbors with [ farm-state = 1 ]

  let seller [belongs-to] of one-of patches-to-buy
  ask patches with [belongs-to = seller ] [
    set pcolor 65
    set belongs-to myself   ;; new owner
    set GW-use GW-use + GW-use-initial * buyinglands-GWU  ; sensitivity analysis
    set GW-use-change buyinglands-GWU     ; sensitivity analysis
    set GW-level-depth GW-level-depth - 2
    set pistachio-production pistachio-production * 1.9
    set farm-state 0
    set well-state 0
  ]
    ask seller [die]    ; the seller farmer leaves this region or emigrates

  ask patches with [belongs-to = myself] [
    set pcolor 65
  ]

end

to-report GW-access

let own-GW-access [ well-depth - GW-level-depth ] of patches with [ belongs-to = myself]  ; Groundwater access is not satisfactory when the difference between the groundwater level depth (from the ground) and well's depth is less than 10 m.
  ifelse max  own-GW-access > GWaccess   ; sensitivity analysis
    [ report true ]
  [ report false]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

 to large-action-list

if policy != 3 [     ; without policy C

  ifelse (ticks mod 5 = 0) [
    if (con2 = true) [ execute-action-2]
  ]
  [priority-2]
  ]


 if policy = 3 [
    ifelse (con5 = true) [execute-action-5]
    [priority-4]
    ]

 end


 to priority-2

  ifelse (con3 = true and con4 = true) [ ifelse ( random 100 >= 50) [ execute-action-3][execute-action-4] ]
                        [ ifelse (con3 = true) [ execute-action-3]
                                        [ ifelse (con4 = true) [ execute-action-4]
                            [ priority-3]
  ]
  ]
 end


 to priority-3
  ifelse (con5 = true) [execute-action-5] [ priority-4]
   end

 to priority-4   ;relocating farms- abandoning farms

  ask patches with [belongs-to = myself] [
    set pcolor brown

    set GW-use 0
    set GW-use-change -1
    set pistachio-production 0
    set farm-state 0
    set well-state 0
  ]
  die      ; this means farmer leaves the region (emigrates).
end


to-report con2    ; for desalination, condition 2 is if the patch (farm) is located in the regions with poor groundwater quality (GW-quality=1) and action of desalination has not been installed in this patch (farm) before.

  ifelse ( act2 = 0 and GW-quality = 1 ) ; act2=0 has not been executed before
  [ report true ]
  [ report false]
end

 to-report con3    ; for purchasing water, condition 3 is if there is any farmer in the neighborhood who is willing to sell-off water

  let my-neighbors (patch-set [ neighbors ] of patches with [belongs-to = myself]) ; without own patches
  let other-my-neighbors my-neighbors with [belongs-to != myself]
  let patches-to-buy-water other-my-neighbors with [ well-state = 1 ]

  ifelse count patches-to-buy-water > 0 [report true] [ report false]

end


to-report con4  ; for deepening wells, condition4 is if the well-depth has not reached the maximum allowed well-depth in that sub-region and the farm is not in the subregions with high land-subsidence (9 is high land subsidence)

      ifelse any? patches with [belongs-to = myself and allowed-well-depth > well-depth and land-subsidence < 9]
  [report true]
  [report false]

end

 to-report con5  ; for shrinking lands, condition 5 is that karge farmers reduce their farms' areas upto 50%.

  let current-land-size count patches with [belongs-to = myself]
  let allowed-land-size round (land-size / 2)
  ifelse ( current-land-size > allowed-land-size + 1 )
  [report true]  [report false]

end

 to execute-action-2 ; desalination

  set  act2  1 ; this action is done and not available anymore

  ask patches with [belongs-to = myself] [  ; and the impacts are implemented
    set pcolor red
    set GW-use GW-use + GW-use-initial * Desalination-GWU    ; sensitivity analysis
    set GW-use-change Desalination-GWU      ; sensitivity analysis
    set GW-level-depth GW-level-depth + 8
    set pistachio-production pistachio-production * 1.9

  ]

end

 to execute-action-3 ; water purchase

  set act3 act3 + 1 ; add number of time water purchased

  let my-neighbors (patch-set [ neighbors ] of patches with [belongs-to = myself])
  let other-my-neighbors my-neighbors with [belongs-to != myself]
  let patches-to-buy other-my-neighbors with [ well-state = 1 ]

  let seller [belongs-to] of one-of patches-to-buy
  ask patches with [belongs-to = seller ] [      ; to implement impacts on the farm of seller
    set GW-use GW-use + GW-use-initial * waterpurchase-GWU    ; sensitivity analysis
    set GW-use-change waterpurchase-GWU    ; sensitivity analysis
    set GW-level-depth GW-level-depth + 8
    set pistachio-production 0
    set well-state 0
  ]

  ask patches with [belongs-to = myself] [         ; to implement impacts on the farms of buyer
    set pcolor turquoise    ;former 65
    set pistachio-production pistachio-production * 1.2
  ]

end


to execute-action-4 ; well deepening
  ask patches with [belongs-to = myself] [          ; to update well-depth after deepening (each time 5m)
  set well-depth well-depth + Welldepth-GWU   ; sensitivity analysis
  ]

  ask patches with [belongs-to = myself] [  ; to implement impacts
    set pcolor blue
    set GW-use GW-use + GW-use-initial * Deepenwell-GWU    ; sensitivity analysis
    set GW-use-change Deepenwell-GWU    ; sensitivity analysis
    set GW-level-depth GW-level-depth + 8
    set pistachio-production pistachio-production * 1.7
  ]

end

to execute-action-5 ; shrinking farms
  ask n-of 2 patches with [belongs-to = myself] [    ;to implement impacts on the patches that are not farm anymore (do not belong to the farmer)
    set belongs-to nobody
    set pcolor 0
    set GW-use 0
    set GW-use-change -1
    set pistachio-production 0
    set farm-state 0
    set well-state 0
  ]

  ask patches with [belongs-to = myself] [  ; to implement impacts on the patches that are still farm (belong to the farmer)
   set pcolor violet
   set GW-use GW-use + GW-use-initial * Shrinkingland-GWU    ; sensitivity analysis
   set GW-use-change Shrinkingland-GWU      ; sensitivity analysis
   set GW-level-depth GW-level-depth - 3
   set pistachio-production pistachio-production * 1.2
  ]

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to medium-action-list

  if policy != 2 and policy != 3 [

    ifelse (con1m = true ) [ execute-action-1m][
    if (con2m = true ) [ execute-action-2m]              ; if to keep this action and continue with other actions at the same time ifelse to just keep it with this action
    ifelse (con3m = true ) [ execute-action-3m][
    ifelse (con4m = true ) [ execute-action-4m][
          execute-action-5m]
      ]
    ]
  ]

    if policy = 2 [

    ifelse (con3m = true ) [ execute-action-3m][
    ifelse (con1m = true ) [ execute-action-1m][
    if (con2m = true ) [ execute-action-2m]              ; if to keep this action and continue with other actions at the same time ifelse to just keep it with this action
    ifelse (con4m = true ) [ execute-action-4m][
          execute-action-5m]
      ]
    ]
  ]

  if policy = 3 [
    if (con2m = true ) [ execute-action-2m]              ; if to keep this action and continue with other actions at the same time ifelse to just keep it with this action
    ifelse (con3m = true ) [ execute-action-3m][
    ifelse (con4m = true ) [ execute-action-4m][
          execute-action-5m]
      ]
    ]

end


to-report con1m   ; for deepening wells

  ifelse any? patches with [belongs-to = myself and allowed-well-depth > well-depth and land-subsidence < 9]
  [report true] [report false]

end

to-report con2m   ; land integration

  let my-neighbors (patch-set [ neighbors ] of patches with [belongs-to = myself])
  let other-my-neighbors my-neighbors with [belongs-to != myself]
  let patches-to-integrate other-my-neighbors with [farm-state = 2]

  ifelse ( count patches-to-integrate > 0 and [farm-state] of one-of patches with [belongs-to = myself] = 0 )
    [report true ]
    [ report false]


end

to-report con3m  ;irrigation modification

  if policy = 2 [
    ifelse (act3-m = 0 )
    [ report true ]
    [ report false ]
  ]

  if policy != 2 [
    ifelse ( act3-m = 0 and land-document = 1)
  [ report true ]
  [report false]
  ]

end


to-report con4m   ; shrinking lands

  let current-land-size count patches with [belongs-to = myself]
  let allowed-land-size round (land-size * 2 / 3)
  ifelse ( current-land-size > allowed-land-size + 1)
  [report true]  [report false]

end

to execute-action-1m    ; deepening wells
    ask patches with [belongs-to = myself] [
  set well-depth well-depth + Welldepth-GWU   ; sensitivity analysis
  ]

  ask patches with [belongs-to = myself] [  ; to implement impacts
    set pcolor blue
    set GW-use GW-use + GW-use-initial * 0.5
    set GW-use-change 0.5
    set GW-level-depth GW-level-depth + 5
    set pistachio-production pistachio-production * 1.9

  ]
end

to execute-action-2m   ; land integration

  let my-neighbors (patch-set [ neighbors ] of patches with [belongs-to = myself])
  let other-my-neighbors my-neighbors with [belongs-to != myself]
  let patches-to-integrate other-my-neighbors with [farm-state = 2]

    ask patches with [belongs-to = myself] [  ; to implement impacts
    set pcolor cyan
    set GW-use GW-use + GW-use-initial * Farmintegration-GWU  ; sensitivity analysis
    set GW-use-change Farmintegration-GWU   ; sensitivity analysis
    set GW-level-depth GW-level-depth - 8
    set pistachio-production pistachio-production * 1.8
  ]

  let selected-farmer [belongs-to] of one-of patches-to-integrate
  ask patches with [belongs-to = selected-farmer ] [
    set pcolor cyan
    set GW-use GW-use + GW-use-initial * -0.7
    set GW-use-change -0.7
    set GW-level-depth GW-level-depth - 8
    set pistachio-production pistachio-production * 1.8
  ]

end

to execute-action-3m   ; irrigation
  set act3-m  1    ; irrigation modification is taken and not available for next steps

 ask patches with [belongs-to = myself] [  ; to implement impacts
    set pcolor magenta
    set GW-use GW-use + GW-use-initial * Irrigationchange-GWU   ; sensitivity analysis
    set GW-use-change Irrigationchange-GWU   ; sesitivity analysis
    set GW-level-depth GW-level-depth - 5
    set pistachio-production pistachio-production * 1.75
  ]

end


to execute-action-4m   ; shrinking
  ask one-of patches with [belongs-to = myself] [
    set belongs-to nobody
    set pcolor 0
    set GW-use 0
    set GW-use-change -1
    set pistachio-production 0
    set farm-state 0
    set well-state 0
  ]
  ask patches with [belongs-to = myself] [  ; to implement impacts
    set GW-use GW-use + GW-use-initial * -0.15
    set GW-use-change -0.15
    set GW-level-depth GW-level-depth - 2
    set pistachio-production pistachio-production * 1.2
    set pcolor violet
  ]

end

to execute-action-5m  ;selling land or water

 if policy != 1 [
  ask patches with [belongs-to = myself][
    set farm-state 1
    set pcolor pink
    if (random 100 >= 50 and well-depth > GW-level-depth) [ ; they can sell water untile the time they have access to water
      set well-state 1
      set pcolor white]
    ]
  ]

  if policy = 1 [
    ask patches with [belongs-to = myself] [
      set pcolor brown

          set GW-use 0
    set GW-use-change -1
    set pistachio-production 0
    set farm-state 0
    set well-state 0
  ]
  die       ; this means farmer leaves the region (emigrates).
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to small-action-list

   ifelse (con1s = true ) [ execute-action-1s]
  [ ifelse (con2s = true ) [ execute-action-2s]
    [execute-action-3s]
    ]

end

to-report con1s ; irrigation system modification

if policy = 2 [ ; policy of solving land-document problem
    ifelse ( act1-s = 0 )
  [ report true ]
  [report false]
  ]

    if policy != 2 [    ; with no policy 2
ifelse ( act1-s = 0 and land-document = 1)
  [ report true ]
  [report false]
  ]

end


to-report con2s
  ifelse (act2-s < 5) ; this is the limit for the action of wels turning off
  [report true]
  [report false]
end

to execute-action-1s  ; irrigation system change
  set act1-s 1

  ask patches with [belongs-to = myself] [
    set GW-use GW-use + GW-use-initial * -0.7
    set GW-use-change -0.7
    set GW-level-depth GW-level-depth - 3
    set pistachio-production pistachio-production * 1.7
    set pcolor magenta
  ]
end


to execute-action-2s   ; wells turn-off
  set act2-s act2-s + 1

  ask patches with [belongs-to = myself] [
    set GW-use GW-use + GW-use-initial * Wellsoff-GWU   ; sensitivity analysis
    set GW-use-change Wellsoff-GWU   ; sensitivity analysis
    set GW-level-depth GW-level-depth - 1
    set pistachio-production pistachio-production * 1.7
    set pcolor sky
  ]
end

to execute-action-3s  ; selling land and water

    if policy != 1 [
  ask patches with [belongs-to = myself] [
    set farm-state 1
    set pcolor pink
    if (random 100 >= 50 and well-depth > GW-level-depth) [   ; they can sell water untile the time they have access to water
    set well-state 1
    set pcolor white]
    ]
  ]

 if policy = 1 [
  ask patches with [belongs-to = myself] [
    set pcolor brown

    set GW-use 0
    set GW-use-change -1
    set pistachio-production 0
    set farm-state 0
    set well-state 0
  ]
  die      ; this means farmer leaves the region (emigrates).
  ]

end
@#$#@#$#@
GRAPHICS-WINDOW
230
12
1013
796
-1
-1
17.22222222222222
1
10
1
1
1
0
0
0
1
-22
22
-22
22
1
1
1
ticks
30.0

BUTTON
25
22
96
59
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
110
22
185
60
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1053
267
1674
534
GW-use-per-patch-cluster (sum)
time
GW-use
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"PC1" 1.0 0 -16777216 true "" "plot sum [GW-use] of patches with [patch-cluster = 1] "
"PC2" 1.0 0 -7500403 true "" "plot sum [GW-use] of patches with [patch-cluster = 2] "
"PC3" 1.0 0 -2674135 true "" "plot sum [GW-use] of patches with [patch-cluster = 3] "
"PC4" 1.0 0 -955883 true "" "plot sum [GW-use] of patches with [patch-cluster = 4] "
"PC5" 1.0 0 -6459832 true "" "plot sum [GW-use] of patches with [patch-cluster = 5] "
"PC6" 1.0 0 -1184463 true "" "plot sum [GW-use] of patches with [patch-cluster = 6] "
"PC7" 1.0 0 -10899396 true "" "plot sum [GW-use] of patches with [patch-cluster = 7] "

PLOT
1052
552
1673
795
NUmber of small and medium farmers
time
number of farmers
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"medium-farmers" 1.0 0 -955883 true "" "plot count medium-farmers"
"small-farmers" 1.0 0 -10263788 true "" "plot count small-farmers"
"large-farmers" 1.0 0 -2674135 true "" "plot count large-farmers"

TEXTBOX
46
612
196
630
Water-purchase
14
75.0
1

TEXTBOX
45
572
195
590
Buying lands
14
65.0
1

TEXTBOX
45
592
195
610
Desalination
14
15.0
1

TEXTBOX
45
633
195
651
Well-deepening
14
105.0
1

TEXTBOX
45
655
195
673
Shrinking-land
14
115.0
1

TEXTBOX
45
680
195
698
Land-integartion
14
85.0
1

TEXTBOX
45
703
195
721
Irrigation-modification
14
125.0
1

TEXTBOX
45
727
195
745
Selling-land
14
135.0
1

TEXTBOX
44
751
194
769
Selling-water
14
0.0
1

TEXTBOX
43
773
193
791
Well-turn-off
14
95.0
1

PLOT
1054
10
1674
250
GW-use of the whole region
Time
GW-use
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot sum [GW-use] of patches "

SLIDER
19
124
191
157
buyinglands-GWU
buyinglands-GWU
-1
0
-0.9
0.1
1
NIL
HORIZONTAL

SLIDER
19
160
191
193
Desalination-GWU
Desalination-GWU
0
1
0.7
0.1
1
NIL
HORIZONTAL

SLIDER
19
196
191
229
waterpurchase-GWU
waterpurchase-GWU
0
1
0.7
0.1
1
NIL
HORIZONTAL

SLIDER
19
232
191
265
Deepenwell-GWU
Deepenwell-GWU
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
20
268
192
301
Shrinkingland-GWU
Shrinkingland-GWU
-1
0
-0.9
0.1
1
NIL
HORIZONTAL

SLIDER
20
304
193
337
Irrigationchange-GWU
Irrigationchange-GWU
-1
0
-0.6
0.1
1
NIL
HORIZONTAL

SLIDER
21
341
193
374
Farmintegration-GWU
Farmintegration-GWU
-1
0
-0.7
0.1
1
NIL
HORIZONTAL

SLIDER
22
378
194
411
Wellsoff-GWU
Wellsoff-GWU
-1
0
-0.3
0.1
1
NIL
HORIZONTAL

SLIDER
22
415
194
448
GWaccess
GWaccess
0
15
10.0
1
1
NIL
HORIZONTAL

SLIDER
23
492
195
525
MaxshrinkL
MaxshrinkL
0
100
50.0
10
1
NIL
HORIZONTAL

SLIDER
23
530
195
563
MaxshrinkM
MaxshrinkM
0
100
50.0
10
1
NIL
HORIZONTAL

SLIDER
19
80
191
113
Policy
Policy
0
3
0.0
1
1
NIL
HORIZONTAL

SLIDER
22
453
194
486
Welldepth-GWU
Welldepth-GWU
0
10
5.0
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This model 1) represents decisions and actions of farmers facing water scarcity in Rafsanjan, Iran to satisfy their groundwater demand for pistachio production, and 2) simulates impacts of different water scarcity policy options on the overall groundwater use in this region. 

## HOW IT WORKS

Agents' behaviour rules (type of actions, order of actions, conditions and impact of actions) are derived from farmers' Fuzzy Cognitive Maps (FCMs) developed via participatory approaches.

## HOW TO USE IT

First the model should be setup ('setup' button top left of interface).
When the setup finishes (the modelles area can be seen in the interface), the model can be run. When the 'go' botton is pressed the model will run for the 180 time steps or 15 year (each time step represents one month).


## THINGS TO TRY

Try simulating impacts of different policies by changing the policy numbers in the policy slider. You can see the overall groundwater use in Rafsanjan, in each sub-region and number of large, medium and small farmers over the next 15 year, by executing each policy.

## EXTENDING THE MODEL

Many extensions are suggested in the associated paper
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person farmer
false
4
Polygon -7500403 true false 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 60 195 90 210 114 154 120 195 180 195 187 157 210 210 240 195 195 90 165 90 150 105 150 150 135 90 105 90
Circle -7500403 true false 110 5 80
Rectangle -7500403 true false 127 79 172 94
Polygon -13345367 true false 120 90 120 180 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 180 90 172 89 165 135 135 135 127 90
Polygon -6459832 true false 116 4 113 21 71 33 71 40 109 48 117 34 144 27 180 26 188 36 224 23 222 14 178 16 167 0
Line -16777216 false 225 90 270 90
Line -16777216 false 225 15 225 90
Line -16777216 false 270 15 270 90
Line -16777216 false 247 15 247 90
Rectangle -6459832 true false 240 90 255 300

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="SA-buyinglands-GWU" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="buyinglands">
      <value value="-0.9"/>
      <value value="-0.8"/>
      <value value="-0.7"/>
      <value value="-0.6"/>
      <value value="-0.5"/>
      <value value="-0.4"/>
      <value value="-0.3"/>
      <value value="-0.2"/>
      <value value="-0.1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA-Desalination-GWU" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="Desalination-GWU">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SA- waterpurchase-GWU" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="waterpurchase-GWU">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Deepenwell-GWU" repetitions="300" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="Deepenwell-GWU">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Shrinkingland-GWU" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="Shrinkingland-GWU">
      <value value="-0.1"/>
      <value value="-0.2"/>
      <value value="-0.3"/>
      <value value="-0.4"/>
      <value value="-0.5"/>
      <value value="-0.6"/>
      <value value="-0.7"/>
      <value value="-0.8"/>
      <value value="-0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Irrigationchange-GWU" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="Irrigationchange-GWU">
      <value value="-0.1"/>
      <value value="-0.2"/>
      <value value="-0.3"/>
      <value value="-0.4"/>
      <value value="-0.5"/>
      <value value="-0.6"/>
      <value value="-0.7"/>
      <value value="-0.8"/>
      <value value="-0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Farmintegration-GWU" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="Farmintegration-GWU">
      <value value="-0.1"/>
      <value value="-0.2"/>
      <value value="-0.3"/>
      <value value="-0.4"/>
      <value value="-0.5"/>
      <value value="-0.6"/>
      <value value="-0.7"/>
      <value value="-0.8"/>
      <value value="-0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="wellsoff-GWU" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="wellsoff-GWU">
      <value value="-0.1"/>
      <value value="-0.2"/>
      <value value="-0.3"/>
      <value value="-0.4"/>
      <value value="-0.5"/>
      <value value="-0.6"/>
      <value value="-0.7"/>
      <value value="-0.8"/>
      <value value="-0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="GWaccess" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="GWaccess">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
      <value value="12"/>
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Welldepth" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="Welldepth">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MaxshrinkL" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="MaxshrinkL">
      <value value="10"/>
      <value value="20"/>
      <value value="30"/>
      <value value="40"/>
      <value value="50"/>
      <value value="60"/>
      <value value="70"/>
      <value value="80"/>
      <value value="90"/>
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MaxshrinkM" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>sum [GW-use] of patches with [patch-cluster = 4]</metric>
    <enumeratedValueSet variable="MaxshrinkM">
      <value value="10"/>
      <value value="20"/>
      <value value="30"/>
      <value value="40"/>
      <value value="50"/>
      <value value="60"/>
      <value value="70"/>
      <value value="80"/>
      <value value="90"/>
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
